==> thunderbird-45.8.0.source.tar.xz: thunderbird-45.8.0/suite/common/places/tests/unit/head_bookmarks.js <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

const Ci = Components.interfaces;
const Cc = Components.classes;
const Cr = Components.results;
const Cu = Components.utils;

Cu.import("resource://gre/modules/Services.jsm");

// Import common head.
var commonFile = do_get_file("../../../../../toolkit/components/places/tests/head_common.js", false);
var uri = Services.io.newFileURI(commonFile);
Services.scriptloader.loadSubScript(uri.spec, this);

// Put any other stuff relative to this test folder below.


XPCOMUtils.defineLazyGetter(this, "PlacesUIUtils", function() {
  Cu.import("resource:///modules/PlacesUIUtils.jsm");
  return PlacesUIUtils;
});


const ORGANIZER_FOLDER_ANNO = "PlacesOrganizer/OrganizerFolder";
const ORGANIZER_QUERY_ANNO = "PlacesOrganizer/OrganizerQuery";


// Needed by some test that relies on having an app  registered.
var XULAppInfo = {
  vendor: "Mozilla",
  name: "PlacesTest",
  ID: "{230de50e-4cd1-11dc-8314-0800200c9a66}",
  version: "1",
  appBuildID: "2007010101",
  platformVersion: "",
  platformBuildID: "2007010101",
  inSafeMode: false,
  logConsoleErrors: true,
  OS: "XPCShell",
  XPCOMABI: "noarch-spidermonkey",

  QueryInterface: XPCOMUtils.generateQI([
    Ci.nsIXULAppInfo,
    Ci.nsIXULRuntime,
  ])
};
var XULAppInfoFactory = {
  createInstance: function (outer, iid) {
  if (outer != null)
    throw Cr.NS_ERROR_NO_AGGREGATION;
  return XULAppInfo.QueryInterface(iid);
  }
};
var registrar = Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
registrar.registerFactory(Components.ID("{fbfae60b-64a4-44ef-a911-08ceb70b9f31}"),
                          "XULAppInfo", "@mozilla.org/xre/app-info;1",
                          XULAppInfoFactory);

// Smart bookmarks constants.
const SMART_BOOKMARKS_VERSION = 4;
// 1 = "Most Visited".
const SMART_BOOKMARKS_ON_TOOLBAR = 1;
// 3 = "Recently Bookmarked", "Recent Tags", separator.
const SMART_BOOKMARKS_ON_MENU = 3; // Takes in count the additional separator.

// Default bookmarks constants.
// 4 =  "SeaMonkey", "mozilla.org", "mozillaZine", "mozdev.org".
const DEFAULT_BOOKMARKS_ON_TOOLBAR = 4;
// 2 = "SeaMonkey and Mozilla", "Search the Web".
const DEFAULT_BOOKMARKS_ON_MENU = 3; // Takes in count the additional separator.

==> thunderbird-50.0b2.source.tar.xz: thunderbird-50.0b2/suite/common/places/tests/unit/head_bookmarks.js <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

const Ci = Components.interfaces;
const Cc = Components.classes;
const Cr = Components.results;
const Cu = Components.utils;

Cu.import("resource://gre/modules/Services.jsm");

// Import common head.
var commonFile = do_get_file("../../../../../toolkit/components/places/tests/head_common.js", false);
var uri = Services.io.newFileURI(commonFile);
Services.scriptloader.loadSubScript(uri.spec, this);

// Put any other stuff relative to this test folder below.


XPCOMUtils.defineLazyGetter(this, "PlacesUIUtils", function() {
  Cu.import("resource:///modules/PlacesUIUtils.jsm");
  return PlacesUIUtils;
});


const ORGANIZER_FOLDER_ANNO = "PlacesOrganizer/OrganizerFolder";
const ORGANIZER_QUERY_ANNO = "PlacesOrganizer/OrganizerQuery";


// Needed by some test that relies on having an app  registered.
Cu.import("resource://testing-common/AppInfo.jsm", this);
updateAppInfo({
  name: "PlacesTest",
  ID: "{230de50e-4cd1-11dc-8314-0800200c9a66}",
  version: "1",
  platformVersion: "",
});

// Smart bookmarks constants.
const SMART_BOOKMARKS_VERSION = 4;
// 1 = "Most Visited".
const SMART_BOOKMARKS_ON_TOOLBAR = 1;
// 3 = "Recently Bookmarked", "Recent Tags", separator.
const SMART_BOOKMARKS_ON_MENU = 3; // Takes in count the additional separator.

// Default bookmarks constants.
// 4 =  "SeaMonkey", "mozilla.org", "mozillaZine", "mozdev.org".
const DEFAULT_BOOKMARKS_ON_TOOLBAR = 4;
// 2 = "SeaMonkey and Mozilla", "Search the Web".
const DEFAULT_BOOKMARKS_ON_MENU = 3; // Takes in count the additional separator.
